@@ -1,6 +1,5 @@
 var dir_b1053a8cf5074fcb3b0c4506b0d7724e =
 [
-    [ "benchmarks", "dir_a24b38fed92ba7510ef914772f5ca04a.html", "dir_a24b38fed92ba7510ef914772f5ca04a" ],
     [ "parsers", "dir_3ed2b71d689fb67b3befc3e35196a5f1.html", "dir_3ed2b71d689fb67b3befc3e35196a5f1" ],
     [ "alloc_engine.cc", "da/db1/alloc__engine_8cc.html", null ],
     [ "alloc_engine.h", "d4/dcf/alloc__engine_8h.html", "d4/dcf/alloc__engine_8h" ],
@@ -30,6 +29,8 @@ var dir_b1053a8cf5074fcb3b0c4506b0d7724e =
     [ "cfg_duid.h", "de/d99/cfg__duid_8h.html", "de/d99/cfg__duid_8h" ],
     [ "cfg_expiration.cc", "d3/d4e/cfg__expiration_8cc.html", null ],
     [ "cfg_expiration.h", "de/df4/cfg__expiration_8h.html", "de/df4/cfg__expiration_8h" ],
+    [ "cfg_globals.cc", "d6/d38/cfg__globals_8cc.html", null ],
+    [ "cfg_globals.h", "da/d3b/cfg__globals_8h.html", "da/d3b/cfg__globals_8h" ],
     [ "cfg_host_operations.cc", "d1/de7/cfg__host__operations_8cc.html", null ],
     [ "cfg_host_operations.h", "d2/d90/cfg__host__operations_8h.html", "d2/d90/cfg__host__operations_8h" ],
     [ "cfg_hosts.cc", "d8/db3/cfg__hosts_8cc.html", null ],
@@ -83,14 +84,6 @@ var dir_b1053a8cf5074fcb3b0c4506b0d7724e =
     [ "config_backend_pool_dhcp6.h", "d1/d4c/config__backend__pool__dhcp6_8h.html", [
       [ "isc::dhcp::ConfigBackendPoolDHCPv6", "d8/dfb/classisc_1_1dhcp_1_1ConfigBackendPoolDHCPv6.html", "d8/dfb/classisc_1_1dhcp_1_1ConfigBackendPoolDHCPv6" ]
     ] ],
-    [ "cql_host_data_source.cc", "d5/d29/cql__host__data__source_8cc.html", "d5/d29/cql__host__data__source_8cc" ],
-    [ "cql_host_data_source.h", "d7/d98/cql__host__data__source_8h.html", [
-      [ "isc::dhcp::CqlHostDataSource", "de/d4d/classisc_1_1dhcp_1_1CqlHostDataSource.html", "de/d4d/classisc_1_1dhcp_1_1CqlHostDataSource" ]
-    ] ],
-    [ "cql_lease_mgr.cc", "df/d2f/cql__lease__mgr_8cc.html", "df/d2f/cql__lease__mgr_8cc" ],
-    [ "cql_lease_mgr.h", "d5/dec/cql__lease__mgr_8h.html", [
-      [ "isc::dhcp::CqlLeaseMgr", "de/dd0/classisc_1_1dhcp_1_1CqlLeaseMgr.html", "de/dd0/classisc_1_1dhcp_1_1CqlLeaseMgr" ]
-    ] ],
     [ "csv_lease_file4.cc", "dc/db8/csv__lease__file4_8cc.html", null ],
     [ "csv_lease_file4.h", "dd/dde/csv__lease__file4_8h.html", [
       [ "isc::dhcp::CSVLeaseFile4", "d4/dac/classisc_1_1dhcp_1_1CSVLeaseFile4.html", "d4/dac/classisc_1_1dhcp_1_1CSVLeaseFile4" ]
@@ -167,6 +160,10 @@ var dir_b1053a8cf5074fcb3b0c4506b0d7724e =
       [ "isc::dhcp::LeaseMgrFactory", "d3/dc6/classisc_1_1dhcp_1_1LeaseMgrFactory.html", null ],
       [ "isc::dhcp::NoLeaseManager", "d3/d76/classisc_1_1dhcp_1_1NoLeaseManager.html", "d3/d76/classisc_1_1dhcp_1_1NoLeaseManager" ]
     ] ],
+    [ "memfile_lease_limits.cc", "db/d2b/memfile__lease__limits_8cc.html", null ],
+    [ "memfile_lease_limits.h", "db/d6e/memfile__lease__limits_8h.html", [
+      [ "isc::dhcp::ClassLeaseCounter", "d6/d50/classisc_1_1dhcp_1_1ClassLeaseCounter.html", "d6/d50/classisc_1_1dhcp_1_1ClassLeaseCounter" ]
+    ] ],
     [ "memfile_lease_mgr.cc", "db/dd3/memfile__lease__mgr_8cc.html", [
       [ "isc::dhcp::LFCSetup", "d7/dae/classisc_1_1dhcp_1_1LFCSetup.html", "d7/dae/classisc_1_1dhcp_1_1LFCSetup" ],
       [ "isc::dhcp::MemfileLeaseStatsQuery", "d2/d28/classisc_1_1dhcp_1_1MemfileLeaseStatsQuery.html", "d2/d28/classisc_1_1dhcp_1_1MemfileLeaseStatsQuery" ],
@@ -228,9 +225,6 @@ var dir_b1053a8cf5074fcb3b0c4506b0d7724e =
     ] ],
     [ "timer_mgr.cc", "d4/d12/timer__mgr_8cc.html", "d4/d12/timer__mgr_8cc" ],
     [ "timer_mgr.h", "d5/d3c/timer__mgr_8h.html", "d5/d3c/timer__mgr_8h" ],
-    [ "triplet.h", "d7/d13/triplet_8h.html", [
-      [ "isc::dhcp::Triplet< T >", "d4/d2d/classisc_1_1dhcp_1_1Triplet.html", "d4/d2d/classisc_1_1dhcp_1_1Triplet" ]
-    ] ],
     [ "utils.h", "d5/d60/utils_8h.html", [
       [ "isc::dhcp::RFCViolation", "d8/de5/classisc_1_1dhcp_1_1RFCViolation.html", "d8/de5/classisc_1_1dhcp_1_1RFCViolation" ]
     ] ],
